from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class SwitchTo(AbstractTask):
	def __execute__(self):
		events.switch_to(self.driver, '#test-switch-to')

	def after_execute(self):
		pass



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class Select(AbstractTask):
	def __execute__(self):
		events.click(self.driver, '$xpath//select[@name="xpath"]/option[@value="option"]')

	def after_execute(self):
		pass



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class NotRequired(AbstractTask):
	def before_execute(self):
		self.required = False

	def __execute__(self):
		events.click(self.driver, '.some-element-that-isn\'t-clickable')

	def after_execute(self):
		pass



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class Click(AbstractTask):
	def __execute__(self):
		events.click(self.driver, '#test-click')

	def after_execute(self):
		self.assert_element_exists('.clicked')



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class CurrentUrl(AbstractTask):
	def __execute__(self):
		events.click(self.driver, '#test-current-url')

	def after_execute(self):
		self.assert_url_equals('http://annahub.se:8000/test/switchto')
		self.assert_in_url('test/switchto')



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class Hover(AbstractTask):
	def __execute__(self):
		events.hover(self.driver, '#test-hover')

	def after_execute(self):
		self.assert_element_exists('.hovered')



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class SendKeys(AbstractTask):
	def __execute__(self):
		events.scroll_to(self.driver, '#iframe-test-send-keys')
		events.send_keys(driver=self.driver, target='#iframe-test-send-keys', value='iframe_test_send_keys')

	def after_execute(self):
		self.assert_element_exists('.iframe_test_send_keys')



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class Wait(AbstractTask):
	def __execute__(self):
		events.scroll_to(self.driver, '#iframe-test-wait')
		events.click(self.driver, '#iframe-test-wait')
		events.wait(self.driver, '#iframe-test-wait-get')

	def after_execute(self):
		self.assert_element_exists('#iframe-test-wait-get')



from anna_lib.selenium import events
from anna_lib.task.abstract_task import AbstractTask


class SendKeys(AbstractTask):
	def __execute__(self):
		events.send_keys(driver=self.driver, target='#test-send-keys', value='test_send_keys')

	def after_execute(self):
		self.assert_element_exists('.test_send_keys')
